@@ -105,7 +105,7 @@ class Style(Element):
         if self.path:
             p = self.experiment.subpath(self.path)
 
-            code = p.read_text()
+            code = p.read_text(encoding="utf-8")
             return [(self.priority, code)]
         else:
             return [(self.priority, self.code)]
@@ -235,7 +235,7 @@ class JavaScript(Element):
         elif self.path:
             p = self.experiment.subpath(self.path)
 
-            code = p.read_text()
+            code = p.read_text(encoding="utf-8")
             return [(self.priority, code)]
         else:
             return [(self.priority, self.code)]
@@ -304,9 +304,9 @@ class Value(InputElement):
 
     """
 
-    def __init__(self, value: Union[str, int, float], name: str):
+    def __init__(self, value: Union[str, int, float], name: str, description: str = ""):
         """Constructor method."""
-        super().__init__(name=name)
+        super().__init__(name=name, description=description)
 
         #: The value that you want to save.
         self.input: Union[str, int, float] = value
