@@ -46,7 +46,7 @@ from cryptography.fernet import Fernet
 
 from . import alfredlog
 from .section import Section, _RootSection, _AbortSection
-from .page import Page
+from .page import Page, _NothingHerePage
 from . import messages, page, section
 from . import saving_agent
 from .alfredlog import QueuedLoggingInterface
@@ -114,6 +114,8 @@ class Experiment:
         #: of the main _content section
         self._root_members: dict = {}
 
+        self._admin = None
+
         #: A list of function that will be called upon creation of an
         #: experiment session. They are added with the :meth:`.setup`
         #: decorator
@@ -256,15 +258,17 @@ class Experiment:
 
         return wrapper
 
-    def member(self, _member=None, *, of_section: str = "_content"):
+    def member(self, _member=None, *, of_section: str = "_content", admin: bool = False):
         """
         Decorator for adding pages and sections to the experiment.
 
         Works both with and without arguments.
 
         Args:
-            of_section: Name of the section to which the new member
+            of_section (str): Name of the section to which the new member
                 belongs.
+            admin (bool): If *True*, the new member will be added to the
+                admin mode instead of the normal experiment.
 
         Examples:
 
@@ -289,8 +293,8 @@ class Experiment:
 
                 @exp.member(of_section="main")
                 class HelloWorld(al.Page):
-                    name = "hello_world"
                     title = "Hello, World!"
+
                     def on_exp_access(self):
                         self += al.Text("This is a 'hello, world!' Page.")
 
@@ -302,7 +306,10 @@ class Experiment:
                 if isclass(member) and not member.name:
                     member.name = member.__name__
 
-                self.append(member, to_section=of_section)
+                if admin:
+                    self.admin.append(member, to_section=of_section)
+                else:
+                    self.append(member, to_section=of_section)
                 return member
 
             return wrapper()
@@ -312,6 +319,16 @@ class Experiment:
         else:
             return add_member(_member)
 
+    @property
+    def admin(self):
+        if not self._admin:
+            self._admin = ExperimentAdmin()
+        return self._admin
+    
+    @admin.setter
+    def admin(self, value):
+        self._admin = value
+
     @property
     def final_page(self):
         """
@@ -408,10 +425,20 @@ class Experiment:
             :class:`.ExperimentSession` contains documentation on how
             to interact with an experiment session object.
 
-        TODO:
-            * Take care of how the condition gets set.
-
         """
+        
+        if urlargs.get("admin") in ["true", "True", "TRUE"]:
+            
+            self.admin.setup_functions += self.setup_functions
+            self.admin.final_page = _NothingHerePage(name="__") # name gets changed automatically by setter
+            exp_session = self.admin.create_session(
+                session_id=session_id, config=config, secrets=secrets, **urlargs
+            )
+            return exp_session
+        
+        if urlargs.get("debug") in ["true", "True", "TRUE"]:
+            config.read_dict({"general": {"debug": True}})
+
         exp_session = ExperimentSession(
             session_id=session_id, config=config, secrets=secrets, **urlargs
         )
@@ -471,7 +498,7 @@ class Experiment:
             name = member.name
             if name in self.members or name in ["_content", "_root", "_finished_section"]:
                 raise ValueError(f"A section or page of name '{name}' already exists.")
-
+            
             member.parent_name = to_section
             member_inst = member() if isclass(member) else member
 
@@ -491,7 +518,16 @@ class Experiment:
             path: Path to the experiment directory, containing script.py.
                 If None, alfred looks for a script.py in the directory
                 from which this method is executed.
-            **kwargs: Keyword arguments passed on to :class:`alfred3.run.ExperimentRunner.auto_run`
+            open_browser: Indicates, whether alfred should try to open
+                a new browser window automatically.
+            debug: Indicates, whether the underlying flask app should be
+                run in debug mode. Defaults to None, which leads to
+                taking the value from option 'open_browser' in section
+                'general' of config.conf.
+            test: If true, the experiment is started in test mode.
+
+        .. versionchanged:: 2.3.0
+            Added parameter *test*.
 
         Notes:
             .. warning::
@@ -518,6 +554,25 @@ class Experiment:
 
                 if __name__ == "__main__":
                     exp.run()
+            
+            To start an experiment in test mode::
+
+                import alfred3 as al
+                exp = al.Experiment()
+                exp += al.Page(name="demo")
+
+                if __name__ == "__main__":
+                    exp.run(test=True)
+            
+            To start an experiment without trying to open a browser
+            window automatically::
+
+                import alfred3 as al
+                exp = al.Experiment()
+                exp += al.Page(name="demo")
+
+                if __name__ == "__main__":
+                    exp.run(open_browser=False)
 
 
         """
@@ -540,6 +595,38 @@ class Experiment:
             raise AttributeError(f"Experiment has no attribute '{name}'.")
 
 
+class ExperimentAdmin(Experiment):
+    
+    def create_session(self, session_id: str, config: ExperimentConfig, secrets: ExperimentSecrets, **urlargs):
+        
+        config.read_dict(self.admin_config)
+
+        exp_session = ExperimentSession(session_id=session_id, config=config, secrets=secrets, **urlargs)
+
+        for fun in self.setup_functions:
+            fun(exp_session)
+
+        exp_session._allow_append = True
+        exp_session.abort_functions.extend(self.abort_functions)
+        exp_session.finish_functions.extend(self.finish_functions)
+
+        exp_session._admin_auth_page_.admin_members = self._root_members
+        
+        if self.final_page is not None:
+            exp_session.final_page = self.final_page
+
+        return exp_session
+    
+    @property
+    def admin_config(self) -> dict:
+        config = {}
+        config["general"] = {"admin": "true"}
+        config["data"] = {"save_data": "false"}
+        config["navigation"] = {"finish": ""}
+
+        return config
+
+
 class ExperimentSession:
     """
     Coordinates all parts of an experiment session.
@@ -657,7 +744,8 @@ class ExperimentSession:
                 f"Experiment version: {self.version}"
             )
         )
-        self._save_data(sync=True)
+        if not self.admin_mode:
+            self._save_data(sync=True)
         
 
     def append_plugin_data_query(self, query: dict):
@@ -765,6 +853,9 @@ class ExperimentSession:
 
     @progress_bar.setter
     def progress_bar(self, bar: elm.display.ProgressBar):
+        if bar is None:
+            self._progress_bar = None
+            return
         if bar.name is not None:
             raise AlfredError(
                 "If you redefine the progress bar, you can't set a custom name. It is fixed to 'progress_bar_'."
@@ -773,7 +864,7 @@ class ExperimentSession:
         bar.added_to_experiment(self)
         self._progress_bar = bar
 
-    def _start(self):
+    def start(self):
         """
         Starts the experiment.
 
@@ -810,6 +901,9 @@ class ExperimentSession:
             In this case, the experiment will immediately jump to page2.
 
         """
+        self._start()
+        
+    def _start(self):
         if self.aborted:
             return
 
@@ -912,7 +1006,13 @@ class ExperimentSession:
         abort_section = _AbortSection(name="_abort_section")
         abort_section += abort_page
 
-        self += abort_section
+        if not self._allow_append:
+            self._allow_append = True
+            self += abort_section
+            self._allow_append = False
+        else:
+            self += abort_section
+
         abort_page._on_showing_widget()
         self.movement_manager._direct_jump(to=pg_name)
 
@@ -1037,7 +1137,7 @@ class ExperimentSession:
         Section: The experiment's main content section, which holds all
         sections and pages added to the experiment.
         """
-        return self.root_section.content
+        return self.root_section._content
 
     @property
     def root_section(self):
@@ -1055,17 +1155,17 @@ class ExperimentSession:
         Excludes the final page.
 
         """
-        return self.root_section.content.all_members
+        return self.root_section._content.all_members
 
     @property
     def all_sections(self) -> dict:
         """dict: Dictionary of all sections in the experiment."""
-        return self.root_section.content.all_subsections
+        return self.root_section._content.all_subsections
 
     @property
     def all_pages(self) -> dict:
         """dict: Dictionary of all pages in the experiment."""
-        return self.root_section.content.all_pages
+        return self.root_section._content.all_pages
 
     @property
     def final_page(self) -> Page:
@@ -1279,6 +1379,39 @@ class ExperimentSession:
         """str: Returns the experiment author."""
         return self.config.get("metadata", "author")
 
+
+    @property
+    def admin_mode(self) -> bool:
+        """bool: Indicates whether the experiment runs in admin mode."""
+        return self.config.getboolean("general", "admin")
+    
+    @property
+    def test_mode(self) -> bool:
+        """
+        bool: Indicates whether the experiment runs in test mode.
+
+        In test mode, alfred3 prefixes all session IDs with ``test``
+        for easy and save separation of test and production sessions.
+
+        You can start the test mode by appending ``test=true`` to
+        alfred3's start url. In a local experiment, this would mean
+        using::
+
+            http://127.0.0.1:5000/start?test=true
+
+        .. warning:: **Keep in mind** that a test session will take up a 
+            slot in list randomization via :class:`.ListRandomizer` just 
+            as any other session. You have to use experiment 
+            version numbers to manage randomization slots. 
+        
+        Notes:
+            The test mode will **also be activated in debug mode**.
+
+        """
+        test_mode = self.urlargs.get("test", False) in ["true", "True", "TRUE"]
+        debug_mode = self.config.getboolean("general", "debug")
+        return test_mode or debug_mode
+
     @property
     def type(self) -> str:
         """str: Type of the experiment"""
@@ -1566,7 +1699,10 @@ class ExperimentSession:
             guidance on how to implement a custom movement method.
 
         """
-        self.movement_manager.forward()
+        try:
+            self.movement_manager._move(direction="forward")
+        except AbortMove:
+            self.log.debug(f"Movement from {self.current_page} in direction 'forward' was aborted.")
 
     def backward(self):
         """
@@ -1580,7 +1716,10 @@ class ExperimentSession:
             guidance on how to implement a custom movement method.
 
         """
-        self.movement_manager.forward()
+        try:
+            self.movement_manager._move(direction="backward")
+        except AbortMove:
+            self.log.debug(f"Movement from {self.current_page} in direction 'backward' was aborted.")
 
     def jump(self, to: Union[str, int]):
         """
@@ -1599,7 +1738,10 @@ class ExperimentSession:
             guidance on how to implement a custom movement method.
 
         """
-        self.movement_manager.jump(to)
+        try:
+            self.movement_manager._move(direction=f"jump>{to}")
+        except AbortMove:
+            self.log.debug(f"Jump from {self.current_page} to page with name '{to}' was aborted.")
 
     @property
     def values(self) -> dict:
@@ -2040,7 +2182,8 @@ class ExperimentSession:
         """
         str: Unique session identifier
         """
-        return self._session_id
+        sid = "test-" + self._session_id if self.test_mode else self._session_id
+        return sid
 
     @property
     def config(self):
