@@ -8,6 +8,7 @@ Pages hold and organize elements.
 import time
 import logging
 import string
+import typing as t
 from abc import ABCMeta, abstractproperty, abstractmethod, ABC
 from builtins import object, str
 from functools import reduce
@@ -17,7 +18,7 @@ from typing import Iterator
 
 from . import alfredlog
 from . import element as elm
-from .element.misc import Style
+from .element.misc import Style, HideNavigation
 from . import saving_agent
 from ._core import ExpMember
 from ._helper import _DictObj
@@ -412,9 +413,6 @@ class _PageCore(ExpMember):
         data = self.experiment.data_manager.session_data
         self.exp.data_saver.main.save_with_all_agents(data=data, level=level, sync=sync)
 
-    def __repr__(self):
-        return f"Page(class='{type(self).__name__}', name='{self.name}')"
-
     def prepare_web_widget(self):
         """
         Hook for computations for preparing a page for display.
@@ -696,6 +694,9 @@ class _CoreCompositePage(_PageCore):
         
         """
 
+        if not self.has_been_shown:
+            return 0
+
         if len(self.show_times) > len(self.hide_times):
             now = time.time()
         elif len(self.show_times) < len(self.hide_times):
@@ -731,7 +732,9 @@ class _CoreCompositePage(_PageCore):
 
         Notes:
             The method *must* return *True* if validation is OK and 
-            *False* if validation fails.
+            *False* if validation fails. You can use 
+            :meth:`.ExperimentSession.post_message` to post a message for
+            participants that will be displayed if validation fails.
 
         Examples:
             ::
@@ -746,7 +749,7 @@ class _CoreCompositePage(_PageCore):
                         self += al.NumberEntry(name="e1", force_input=True)
                         self += al.NumberEntry(name="e2", force_input=True)
                     
-                    def validate_page(self):
+                    def validate(self):
                         e1 = int(self.exp.values.get("e1"))
                         e2 = int(self.exp.values.get("e2"))
                         
@@ -1283,7 +1286,7 @@ class AutoClosePage(TimeoutPage):
 @inherit_kwargs
 class NoDataPage(Page):
     """
-    A page that does not save any data.
+    A page that does not collect any data.
 
     Args:
         {kwargs}
@@ -1296,7 +1299,23 @@ class NoDataPage(Page):
     
     See Also:
         See :class:`.NoSavingPage` for a page that does not trigger a
-        saving event.
+        saving event, but still collects data.
+    
+    Examples:
+    
+        A simple NoDataPage::
+
+            import alfred3 as al
+            exp = al.Experiment()
+
+            @exp.meber
+            class DemoPage1(al.NoDataPage):
+                title = "My demo page"
+
+                def on_exp_access(self):
+                    self += al.TextEntry(placeholder="Enter something", name="el1")
+                    self += al.Alert(text="Note: input to this element WILL NOT BE SAVED!", category="danger")
+
     """
 
     data = {}
@@ -1321,6 +1340,12 @@ class NoSavingPage(Page):
         experiment. To prevent this, you can switch the option 
         'save_data' in section 'data' of config.conf to 'false'.
 
+    .. warning:: Note that a NoSavingPage does not trigger a saving 
+        event, but it does collect data! If a later page triggers a 
+        saving event, data from the NoSavingPage will be saved to the 
+        experiment data! To prevent this behavior, use a :class:`.NoDataPage`
+        instead of NoSavingPage.
+
     See Also:
         See :class:`.NoDataPage` for a page that does not collect any
         data.
@@ -1331,46 +1356,36 @@ class NoSavingPage(Page):
 
             import alfred3 as al
             exp = al.Experiment()
-            exp += al.NoSavingPage(name="demo")
+
+            @exp.meber
+            class DemoPage1(al.NoSavingPage):
+                title = "My demo page"
+
+                def on_exp_access(self):
+                    self += al.TextEntry(placeholder="Enter something", name="el1")
+            
+
+            @exp.member
+            class DemoPage2(al.Page):
+                title = "My second demo page"
+
+                def on_first_show(self):
+                    user_input = self.exp.values.get("el1")
+                    self += al.Text(text=f"You input on the previous page: {{user_input}}")
+
+                    self += al.Text(text="Note that a 'NoSavingPage' does not trigger a saving event, but it does collect data! If a later page triggers a saving event, data from the 'NoSavingPage' will be saved to the experiment data! To prevent this behavior, use a 'NoDataPage' instead of 'NoSavingPage'.")
+
 
         Example 2, a NoSavingPage that also does not collect any data::
 
             import alfred3 as al
             exp = al.Experiment()
 
+            @exp.member
             class NoDataNoSavingPage(al.NoSavingPage):
 
                 data = {{}}
             
-            exp += NoDataNoSavingPage(name="demo")
-        
-        Example 3, a more elaborate example. Here, we create an 
-        experiment with an "admin" mode, triggered by an url parameter,
-        in which no data will be saved.
-        Note that, if we use this method, we do not even need to use
-        a NoSavingPage::
-
-            import alfred3 as al
-            exp = al.Experiment()
-
-            @exp.setup
-            def setup(exp):
-                admin = exp.urlargs.get("admin", False)
-                if admin == "true":
-                    exp.config.read_dict({{"data": {{"save_data": "false"}}}})
-                    exp.log.info("Admin mode triggered. No data will be saved")
-
-            exp += al.Page(name="demo")
-        
-        If this experiment is started with the suffix ``?admin=true`` to
-        the starting url, no data will be saved. In case of a locally 
-        running experiment, the url would be 
-        http://localhost:5000/start?admin=true
-
-        .. note:: Note that the experiment will most likely crash, if
-            the /start route gets called twice for any reason in a local
-            experiment.
-
     """
 
     def save_data(self, *args, **kwargs):
@@ -1617,11 +1632,84 @@ class _DefaultFinalPage(Page):
     The default final page.
     """
 
-    title = "Experiment beendet"
-
     def on_exp_access(self):
-        txt = "Das Experiment ist nun beendet.<br>Vielen Dank für die Teilnahme."
+        self.title = self.exp.config.get("hints", "final_page_title")
+        txt = self.exp.config.get("hints", "final_page_text")
         self += elm.display.Text(":mortar_board:", font_size=70, align="center")
         self += elm.display.VerticalSpace("20px")
         self += elm.display.Text(text=txt, align="center")
         self += elm.misc.WebExitEnabler()
+
+
+class _NothingHerePage(Page):
+
+    title = "There's nothing here"
+
+    def on_exp_access(self):
+        self += elm.display.VerticalSpace("30px")
+        self += elm.display.Text(":heavy_minus_sign:", font_size=70, align="center")
+        self += elm.misc.WebExitEnabler()
+
+
+@inherit_kwargs
+class PasswordPage(WidePage):
+    """
+    A wide page that requires the input of a password for continuation.
+    
+    Args:
+        password: A string, or a tuple of strings. Those are the accepted
+            passwords.
+        {kwargs}
+    
+    Examples:
+
+        A minimal experiment with a password page::
+
+            import alfred3 as al
+            exp = al.Experiment()
+
+            @exp.member
+            class Demo(al.PasswordPage):
+                password = "test"
+
+    """
+    password = None
+    title = "Password required"
+
+    def __init__(self, password: t.Union[str, t.Tuple[str]] = None, **kwargs):
+        super().__init__(**kwargs)
+        if password is not None:
+            self.password = password
+        if self.password is None or not len(self.password):
+            raise ValueError("PasswordPage must have at least one password.")
+        
+        if not isinstance(self.password, (str, list, tuple)):
+            raise ValueError(f"Argument 'password' of {type(self).__name__} must be a string, list, or tuple.")
+
+    def on_exp_access(self):
+        self += HideNavigation()
+        self += elm.display.Text(":closed_lock_with_key:", font_size=70, align="center")
+        self += elm.display.VerticalSpace("20px")
+
+        # use single password or multiple password element depending on input
+        pwargs = dict(toplab="Please enter the password to continue", width="wide", name="pw", align="center", force_input=True)
+        if isinstance(self.password, str):
+            self += elm.input.PasswordEntry(password=self.password, **pwargs)
+        else:
+            self += elm.input.MultiplePasswordEntry(passwords=self.password, **pwargs)
+
+        self += elm.action.SubmittingButtons(
+            "Submit", align="center", name="pw_submit", width="narrow", button_style="btn-primary"
+        )
+
+        # enables submit via enter-press for password field
+        self += elm.misc.JavaScript(
+            code="""$('#pw').on("keydown", function(event) {
+        if (event.key == "Enter") {
+            $("#alt-submit").attr("name", "move");
+            $("#alt-submit").val("forward");
+            $("#form").submit();
+            }});"""
+        )
+
+
